go.tools: use golang.org/x/... import paths

Rewrite performed with this command:
  sed -i '' 's_code.google.com/p/go\._golang.org/x/_g' \
    $(grep -lr 'code.google.com/p/go.' *)

LGTM=rsc
R=rsc
CC=golang-codereviews
https://golang.org/cl/170920043
diff --git a/astutil/enclosing_test.go b/astutil/enclosing_test.go
index 18b911d..ace6974 100644
--- a/astutil/enclosing_test.go
+++ b/astutil/enclosing_test.go
@@ -18,7 +18,7 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/astutil"
+	"golang.org/x/tools/astutil"
 )
 
 // pathToString returns a string containing the concrete types of the
diff --git a/blog/blog.go b/blog/blog.go
index 148bbef..b53cf5b 100644
--- a/blog/blog.go
+++ b/blog/blog.go
@@ -20,8 +20,8 @@
 	"strings"
 	"time"
 
-	"code.google.com/p/go.tools/blog/atom"
-	"code.google.com/p/go.tools/present"
+	"golang.org/x/tools/blog/atom"
+	"golang.org/x/tools/present"
 )
 
 var validJSONPFunc = regexp.MustCompile(`(?i)^[a-z_][a-z0-9_.]*$`)
diff --git a/cmd/cover/func.go b/cmd/cover/func.go
index 2ec57cf..41d9fce 100644
--- a/cmd/cover/func.go
+++ b/cmd/cover/func.go
@@ -17,7 +17,7 @@
 	"path/filepath"
 	"text/tabwriter"
 
-	"code.google.com/p/go.tools/cover"
+	"golang.org/x/tools/cover"
 )
 
 // funcOutput takes two file names as arguments, a coverage profile to read as input and an output
diff --git a/cmd/cover/html.go b/cmd/cover/html.go
index e132cf2..f6b2264 100644
--- a/cmd/cover/html.go
+++ b/cmd/cover/html.go
@@ -17,7 +17,7 @@
 	"path/filepath"
 	"runtime"
 
-	"code.google.com/p/go.tools/cover"
+	"golang.org/x/tools/cover"
 )
 
 // htmlOutput reads the profile data from profile and generates an HTML
diff --git a/cmd/digraph/digraph.go b/cmd/digraph/digraph.go
index 0d3868c..a5c623b 100644
--- a/cmd/digraph/digraph.go
+++ b/cmd/digraph/digraph.go
@@ -74,7 +74,7 @@
 
    Show the transitive closure of imports of the digraph tool itself:
    % go list -f '{{.ImportPath}}{{.Imports}}' ... | tr '[]' '  ' |
-         digraph forward code.google.com/p/go.tools/cmd/digraph
+         digraph forward golang.org/x/tools/cmd/digraph
 
    Show which clothes (see above) must be donned before a jacket:
    %  digraph reverse jacket <clothes.txt
diff --git a/cmd/eg/eg.go b/cmd/eg/eg.go
index 320e179..01dd5a9 100644
--- a/cmd/eg/eg.go
+++ b/cmd/eg/eg.go
@@ -12,8 +12,8 @@
 	"path/filepath"
 	"strings"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/refactor/eg"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/refactor/eg"
 )
 
 var (
diff --git a/cmd/godex/doc.go b/cmd/godex/doc.go
index cf17c6a..90268e2 100644
--- a/cmd/godex/doc.go
+++ b/cmd/godex/doc.go
@@ -21,7 +21,7 @@
 //
 // godex automatically tries all possible package path prefixes if only a
 // partial package path is given. For instance, for the path "go/types",
-// godex prepends "code.google.com/p/go.tools".
+// godex prepends "golang.org/x/tools".
 //
 // The prefixes are computed by searching the directories specified by
 // the GOROOT and GOPATH environment variables (and by excluding the
diff --git a/cmd/godex/gc.go b/cmd/godex/gc.go
index aa4979f..85335b9 100644
--- a/cmd/godex/gc.go
+++ b/cmd/godex/gc.go
@@ -7,7 +7,7 @@
 package main
 
 import (
-	"code.google.com/p/go.tools/go/gcimporter"
+	"golang.org/x/tools/go/gcimporter"
 )
 
 func init() {
diff --git a/cmd/godex/gccgo.go b/cmd/godex/gccgo.go
index c2c10b1..aee2d8e 100644
--- a/cmd/godex/gccgo.go
+++ b/cmd/godex/gccgo.go
@@ -7,8 +7,8 @@
 package main
 
 import (
-	"code.google.com/p/go.tools/go/gccgoimporter"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/gccgoimporter"
+	"golang.org/x/tools/go/types"
 )
 
 var (
diff --git a/cmd/godex/godex.go b/cmd/godex/godex.go
index bdfa236..dee0990 100644
--- a/cmd/godex/godex.go
+++ b/cmd/godex/godex.go
@@ -14,7 +14,7 @@
 	"path/filepath"
 	"strings"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 var (
diff --git a/cmd/godex/print.go b/cmd/godex/print.go
index d40160d..e519f41 100644
--- a/cmd/godex/print.go
+++ b/cmd/godex/print.go
@@ -11,8 +11,8 @@
 	"io"
 	"math/big"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 // TODO(gri) use tabwriter for alignment?
diff --git a/cmd/godex/source.go b/cmd/godex/source.go
index 0f527d1..22d7813 100644
--- a/cmd/godex/source.go
+++ b/cmd/godex/source.go
@@ -7,7 +7,7 @@
 package main
 
 import (
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 func init() {
diff --git a/cmd/godex/writetype.go b/cmd/godex/writetype.go
index 8f80283..10c8e65 100644
--- a/cmd/godex/writetype.go
+++ b/cmd/godex/writetype.go
@@ -12,7 +12,7 @@
 
 package main
 
-import "code.google.com/p/go.tools/go/types"
+import "golang.org/x/tools/go/types"
 
 func (p *printer) writeType(this *types.Package, typ types.Type) {
 	p.writeTypeInternal(this, typ, make([]types.Type, 8))
diff --git a/cmd/godoc/README.godoc-app b/cmd/godoc/README.godoc-app
index 20ae100..50a0516 100644
--- a/cmd/godoc/README.godoc-app
+++ b/cmd/godoc/README.godoc-app
@@ -10,7 +10,7 @@
 * Go sources at tip under $GOROOT
 
 * Godoc sources at tip inside $GOPATH
-  (go get -d code.google.com/p/go.tools/cmd/godoc)
+  (go get -d golang.org/x/tools/cmd/godoc)
 
 
 Directory structure
@@ -23,7 +23,7 @@
   app-engine release and version of godoc):
 
 	app.yaml
-	code.google.com/p/go.tools/cmd/godoc
+	golang.org/x/tools/cmd/godoc
 	godoc.zip
 	index.split.*
 
diff --git a/cmd/godoc/appinit.go b/cmd/godoc/appinit.go
index d2de96e..d91c84f 100644
--- a/cmd/godoc/appinit.go
+++ b/cmd/godoc/appinit.go
@@ -14,11 +14,11 @@
 	"log"
 	"path"
 
-	"code.google.com/p/go.tools/godoc"
-	"code.google.com/p/go.tools/godoc/static"
-	"code.google.com/p/go.tools/godoc/vfs"
-	"code.google.com/p/go.tools/godoc/vfs/mapfs"
-	"code.google.com/p/go.tools/godoc/vfs/zipfs"
+	"golang.org/x/tools/godoc"
+	"golang.org/x/tools/godoc/static"
+	"golang.org/x/tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs/mapfs"
+	"golang.org/x/tools/godoc/vfs/zipfs"
 )
 
 func init() {
diff --git a/cmd/godoc/blog.go b/cmd/godoc/blog.go
index ddaa2c4..dec4732f 100644
--- a/cmd/godoc/blog.go
+++ b/cmd/godoc/blog.go
@@ -15,12 +15,12 @@
 	"strings"
 	"sync"
 
-	"code.google.com/p/go.tools/blog"
-	"code.google.com/p/go.tools/godoc/redirect"
+	"golang.org/x/tools/blog"
+	"golang.org/x/tools/godoc/redirect"
 )
 
 const (
-	blogRepo = "code.google.com/p/go.blog"
+	blogRepo = "golang.org/x/blog"
 	blogURL  = "http://blog.golang.org/"
 	blogPath = "/blog/"
 )
diff --git a/cmd/godoc/codewalk.go b/cmd/godoc/codewalk.go
index 5885c78..e3bf5cd 100644
--- a/cmd/godoc/codewalk.go
+++ b/cmd/godoc/codewalk.go
@@ -29,8 +29,8 @@
 	"text/template"
 	"unicode/utf8"
 
-	"code.google.com/p/go.tools/godoc"
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 var codewalkHTML, codewalkdirHTML *template.Template
diff --git a/cmd/godoc/handlers.go b/cmd/godoc/handlers.go
index 66abbef..1f79d80 100644
--- a/cmd/godoc/handlers.go
+++ b/cmd/godoc/handlers.go
@@ -17,9 +17,9 @@
 	"net/http"
 	"text/template"
 
-	"code.google.com/p/go.tools/godoc"
-	"code.google.com/p/go.tools/godoc/redirect"
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc"
+	"golang.org/x/tools/godoc/redirect"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 var (
diff --git a/cmd/godoc/main.go b/cmd/godoc/main.go
index 30caa2a..318726d 100644
--- a/cmd/godoc/main.go
+++ b/cmd/godoc/main.go
@@ -44,18 +44,18 @@
 	"runtime"
 	"strings"
 
-	"code.google.com/p/go.tools/godoc"
-	"code.google.com/p/go.tools/godoc/analysis"
-	"code.google.com/p/go.tools/godoc/static"
-	"code.google.com/p/go.tools/godoc/vfs"
-	"code.google.com/p/go.tools/godoc/vfs/gatefs"
-	"code.google.com/p/go.tools/godoc/vfs/mapfs"
-	"code.google.com/p/go.tools/godoc/vfs/zipfs"
+	"golang.org/x/tools/godoc"
+	"golang.org/x/tools/godoc/analysis"
+	"golang.org/x/tools/godoc/static"
+	"golang.org/x/tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs/gatefs"
+	"golang.org/x/tools/godoc/vfs/mapfs"
+	"golang.org/x/tools/godoc/vfs/zipfs"
 )
 
 const (
 	defaultAddr = ":6060" // default webserver address
-	toolsPath   = "code.google.com/p/go.tools/cmd/"
+	toolsPath   = "golang.org/x/tools/cmd/"
 )
 
 var (
diff --git a/cmd/godoc/play.go b/cmd/godoc/play.go
index 61a5c45..a56ffe2 100644
--- a/cmd/godoc/play.go
+++ b/cmd/godoc/play.go
@@ -12,7 +12,7 @@
 
 	// This package registers "/compile" and "/share" handlers
 	// that redirect to the golang.org playground.
-	_ "code.google.com/p/go.tools/playground"
+	_ "golang.org/x/tools/playground"
 )
 
 func init() {
diff --git a/cmd/godoc/setup-godoc-app.bash b/cmd/godoc/setup-godoc-app.bash
index 4bc2787..284df8b 100755
--- a/cmd/godoc/setup-godoc-app.bash
+++ b/cmd/godoc/setup-godoc-app.bash
@@ -21,7 +21,7 @@
 ZIPFILE=godoc.zip
 INDEXFILE=godoc.index
 SPLITFILES=index.split.
-GODOC=code.google.com/p/go.tools/cmd/godoc
+GODOC=golang.org/x/tools/cmd/godoc
 CONFIGFILE=$GODOC/appconfig.go
 
 error() {
diff --git a/cmd/goimports/doc.go b/cmd/goimports/doc.go
index 7a39da1..a64ad93 100644
--- a/cmd/goimports/doc.go
+++ b/cmd/goimports/doc.go
@@ -3,7 +3,7 @@
 Command goimports updates your Go import lines,
 adding missing ones and removing unreferenced ones.
 
-     $ go get code.google.com/p/go.tools/cmd/goimports
+     $ go get golang.org/x/tools/cmd/goimports
 
 It's a drop-in replacement for your editor's gofmt-on-save hook.
 It has the same command-line interface as gofmt and formats
diff --git a/cmd/goimports/goimports.go b/cmd/goimports/goimports.go
index a344854..a008d82 100644
--- a/cmd/goimports/goimports.go
+++ b/cmd/goimports/goimports.go
@@ -17,7 +17,7 @@
 	"runtime"
 	"strings"
 
-	"code.google.com/p/go.tools/imports"
+	"golang.org/x/tools/imports"
 )
 
 var (
diff --git a/cmd/gorename/main.go b/cmd/gorename/main.go
index 8ba61f8..20e271e 100644
--- a/cmd/gorename/main.go
+++ b/cmd/gorename/main.go
@@ -10,7 +10,7 @@
 	"os"
 	"runtime"
 
-	"code.google.com/p/go.tools/refactor/rename"
+	"golang.org/x/tools/refactor/rename"
 )
 
 var (
diff --git a/cmd/gotype/gotype.go b/cmd/gotype/gotype.go
index 2479ecd..4a5c7de 100644
--- a/cmd/gotype/gotype.go
+++ b/cmd/gotype/gotype.go
@@ -18,9 +18,9 @@
 	"runtime"
 	"time"
 
-	"code.google.com/p/go.tools/go/gccgoimporter"
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/gccgoimporter"
+	_ "golang.org/x/tools/go/gcimporter"
+	"golang.org/x/tools/go/types"
 )
 
 var (
diff --git a/cmd/oracle/emacs-test.bash b/cmd/oracle/emacs-test.bash
index b3f7af6..8c39091 100755
--- a/cmd/oracle/emacs-test.bash
+++ b/cmd/oracle/emacs-test.bash
@@ -21,7 +21,7 @@
 trap "rm -f $log" EXIT
 
 # Build and install oracle.
-go get code.google.com/p/go.tools/cmd/oracle || die "'go get' failed"
+go get golang.org/x/tools/cmd/oracle || die "'go get' failed"
 mv -f $GOPATH/bin/oracle $GOROOT/bin/
 $GOROOT/bin/oracle >$log 2>&1 || true # (prints usage and exits 1)
 grep -q "Run.*help" $log || die "$GOROOT/bin/oracle not installed"
@@ -34,7 +34,7 @@
     --load $thisdir/oracle.el \
     --eval '
 (progn
-  (setq go-oracle-scope "code.google.com/p/go.tools/cmd/oracle")
+  (setq go-oracle-scope "golang.org/x/tools/cmd/oracle")
   (find-file "'$thisdir'/main.go")
   (search-forward "\"fmt\"")
   (backward-char)
diff --git a/cmd/oracle/main.go b/cmd/oracle/main.go
index 580fd6c..cdf5329 100644
--- a/cmd/oracle/main.go
+++ b/cmd/oracle/main.go
@@ -23,8 +23,8 @@
 	"runtime"
 	"runtime/pprof"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/oracle"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/oracle"
 )
 
 var posFlag = flag.String("pos", "",
@@ -69,8 +69,8 @@
 Examples:
 
 Describe the syntax at offset 530 in this file (an import spec):
-% oracle -pos=src/code.google.com/p/go.tools/cmd/oracle/main.go:#530 describe \
-   code.google.com/p/go.tools/cmd/oracle
+% oracle -pos=src/golang.org/x/tools/cmd/oracle/main.go:#530 describe \
+   golang.org/x/tools/cmd/oracle
 
 Print the callgraph of the trivial web-server in JSON format:
 % oracle -format=json $GOROOT/src/net/http/triv.go callgraph
diff --git a/cmd/oracle/oracle.el b/cmd/oracle/oracle.el
index dacf9da..35cd892 100644
--- a/cmd/oracle/oracle.el
+++ b/cmd/oracle/oracle.el
@@ -3,7 +3,7 @@
 ;;;
 ;;; To install the Go oracle, run:
 ;;; % export GOROOT=... GOPATH=...
-;;; % go get code.google.com/p/go.tools/cmd/oracle
+;;; % go get golang.org/x/tools/cmd/oracle
 ;;; % mv $GOPATH/bin/oracle $GOROOT/bin/
 ;;;
 ;;; Load this file into Emacs and set go-oracle-scope to your
diff --git a/cmd/present/appengine.go b/cmd/present/appengine.go
index b7d8574..7df536c 100644
--- a/cmd/present/appengine.go
+++ b/cmd/present/appengine.go
@@ -9,9 +9,9 @@
 import (
 	"mime"
 
-	"code.google.com/p/go.tools/present"
+	"golang.org/x/tools/present"
 
-	_ "code.google.com/p/go.tools/playground"
+	_ "golang.org/x/tools/playground"
 )
 
 var basePath = "./present/"
diff --git a/cmd/present/dir.go b/cmd/present/dir.go
index dd3e081..26392dc 100644
--- a/cmd/present/dir.go
+++ b/cmd/present/dir.go
@@ -13,7 +13,7 @@
 	"path/filepath"
 	"sort"
 
-	"code.google.com/p/go.tools/present"
+	"golang.org/x/tools/present"
 )
 
 func init() {
diff --git a/cmd/present/doc.go b/cmd/present/doc.go
index 39f6d41..1b81c31 100644
--- a/cmd/present/doc.go
+++ b/cmd/present/doc.go
@@ -8,7 +8,7 @@
 
 It may be run as a stand-alone command or an App Engine app.
 Instructions for deployment to App Engine are in the README of the
-code.google.com/p/go.tools repository.
+golang.org/x/tools repository.
 
 Usage of present:
   -base="": base path for slide template and static resources
@@ -26,6 +26,6 @@
 	.article      // article format, such as a blog post
 
 The present file format is documented by the present package:
-http://godoc.org/code.google.com/p/go.tools/present
+http://godoc.org/golang.org/x/tools/present
 */
 package main
diff --git a/cmd/present/local.go b/cmd/present/local.go
index 294a524..d91dcc2 100644
--- a/cmd/present/local.go
+++ b/cmd/present/local.go
@@ -18,11 +18,11 @@
 	"runtime"
 	"strings"
 
-	"code.google.com/p/go.tools/playground/socket"
-	"code.google.com/p/go.tools/present"
+	"golang.org/x/tools/playground/socket"
+	"golang.org/x/tools/present"
 )
 
-const basePkg = "code.google.com/p/go.tools/cmd/present"
+const basePkg = "golang.org/x/tools/cmd/present"
 
 var basePath string
 
diff --git a/cmd/present/play.go b/cmd/present/play.go
index 617d2c1..831b99f 100644
--- a/cmd/present/play.go
+++ b/cmd/present/play.go
@@ -12,7 +12,7 @@
 	"path/filepath"
 	"time"
 
-	"code.google.com/p/go.tools/godoc/static"
+	"golang.org/x/tools/godoc/static"
 )
 
 var scripts = []string{"jquery.js", "jquery-ui.js", "playground.js", "play.js"}
diff --git a/cmd/ssadump/main.go b/cmd/ssadump/main.go
index f955783..f063659 100644
--- a/cmd/ssadump/main.go
+++ b/cmd/ssadump/main.go
@@ -13,10 +13,10 @@
 	"runtime"
 	"runtime/pprof"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/interp"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/interp"
+	"golang.org/x/tools/go/types"
 )
 
 var buildFlag = flag.String("build", "", `Options controlling the SSA builder.
diff --git a/cmd/stringer/stringer.go b/cmd/stringer/stringer.go
index bc3af18..33343de 100644
--- a/cmd/stringer/stringer.go
+++ b/cmd/stringer/stringer.go
@@ -74,10 +74,10 @@
 	"sort"
 	"strings"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
+	_ "golang.org/x/tools/go/gcimporter"
 )
 
 var (
@@ -91,7 +91,7 @@
 	fmt.Fprintf(os.Stderr, "\tstringer [flags] -type T [directory]\n")
 	fmt.Fprintf(os.Stderr, "\tstringer [flags[ -type T files... # Must be a single package\n")
 	fmt.Fprintf(os.Stderr, "For more information, see:\n")
-	fmt.Fprintf(os.Stderr, "\thttp://godoc.org/code.google.com/p/go.tools/cmd/stringer\n")
+	fmt.Fprintf(os.Stderr, "\thttp://godoc.org/golang.org/x/tools/cmd/stringer\n")
 	fmt.Fprintf(os.Stderr, "Flags:\n")
 	flag.PrintDefaults()
 	os.Exit(2)
diff --git a/cmd/vet/composite.go b/cmd/vet/composite.go
index 408fb37..0c3f916 100644
--- a/cmd/vet/composite.go
+++ b/cmd/vet/composite.go
@@ -11,7 +11,7 @@
 	"go/ast"
 	"strings"
 
-	"code.google.com/p/go.tools/cmd/vet/whitelist"
+	"golang.org/x/tools/cmd/vet/whitelist"
 )
 
 var compositeWhiteList = flag.Bool("compositewhitelist", true, "use composite white list; for testing only")
diff --git a/cmd/vet/copylock.go b/cmd/vet/copylock.go
index 48b7e96..e8a6820 100644
--- a/cmd/vet/copylock.go
+++ b/cmd/vet/copylock.go
@@ -12,7 +12,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 func init() {
diff --git a/cmd/vet/main.go b/cmd/vet/main.go
index 622acb7..a58e18a 100644
--- a/cmd/vet/main.go
+++ b/cmd/vet/main.go
@@ -21,8 +21,8 @@
 	"strconv"
 	"strings"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	"code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	"golang.org/x/tools/go/types"
 )
 
 // TODO: Need a flag to set build tags when parsing the package.
@@ -159,7 +159,7 @@
 	fmt.Fprintf(os.Stderr, "\tvet [flags] directory...\n")
 	fmt.Fprintf(os.Stderr, "\tvet [flags] files... # Must be a single package\n")
 	fmt.Fprintf(os.Stderr, "For more information run\n")
-	fmt.Fprintf(os.Stderr, "\tgodoc code.google.com/p/go.tools/cmd/vet\n\n")
+	fmt.Fprintf(os.Stderr, "\tgodoc golang.org/x/tools/cmd/vet\n\n")
 	fmt.Fprintf(os.Stderr, "Flags:\n")
 	flag.PrintDefaults()
 	os.Exit(2)
diff --git a/cmd/vet/nilfunc.go b/cmd/vet/nilfunc.go
index b89af41..fa1bac7 100644
--- a/cmd/vet/nilfunc.go
+++ b/cmd/vet/nilfunc.go
@@ -13,7 +13,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 func init() {
diff --git a/cmd/vet/print.go b/cmd/vet/print.go
index 3288d59..14de6ab 100644
--- a/cmd/vet/print.go
+++ b/cmd/vet/print.go
@@ -15,8 +15,8 @@
 	"strings"
 	"unicode/utf8"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 var printfuncs = flag.String("printfuncs", "", "comma-separated list of print function names to check")
diff --git a/cmd/vet/shadow.go b/cmd/vet/shadow.go
index 4fc8cb7..34e5db9 100644
--- a/cmd/vet/shadow.go
+++ b/cmd/vet/shadow.go
@@ -35,7 +35,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 var strictShadowing = flag.Bool("shadowstrict", false, "whether to be strict about shadowing; can be noisy")
diff --git a/cmd/vet/shift.go b/cmd/vet/shift.go
index 1f9f804..2385c23 100644
--- a/cmd/vet/shift.go
+++ b/cmd/vet/shift.go
@@ -12,8 +12,8 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 func init() {
diff --git a/cmd/vet/types.go b/cmd/vet/types.go
index 9f762dd..0a2a248 100644
--- a/cmd/vet/types.go
+++ b/cmd/vet/types.go
@@ -10,7 +10,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // imports is the canonical map of imported packages we need for typechecking.
diff --git a/cmd/vet/unsafeptr.go b/cmd/vet/unsafeptr.go
index 652ffbf..ca15f72 100644
--- a/cmd/vet/unsafeptr.go
+++ b/cmd/vet/unsafeptr.go
@@ -10,7 +10,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 func init() {
diff --git a/container/intsets/sparse_test.go b/container/intsets/sparse_test.go
index 727e167..a00cbb3 100644
--- a/container/intsets/sparse_test.go
+++ b/container/intsets/sparse_test.go
@@ -12,7 +12,7 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/container/intsets"
+	"golang.org/x/tools/container/intsets"
 )
 
 func TestBasics(t *testing.T) {
diff --git a/dashboard/app/build/dash.go b/dashboard/app/build/dash.go
index 52ca74d..e00b031 100644
--- a/dashboard/app/build/dash.go
+++ b/dashboard/app/build/dash.go
@@ -61,47 +61,47 @@
 	{
 		Kind: "subrepo",
 		Name: "go.blog",
-		Path: "code.google.com/p/go.blog",
+		Path: "golang.org/x/blog",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.codereview",
-		Path: "code.google.com/p/go.codereview",
+		Path: "golang.org/x/codereview",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.crypto",
-		Path: "code.google.com/p/go.crypto",
+		Path: "golang.org/x/crypto",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.exp",
-		Path: "code.google.com/p/go.exp",
+		Path: "golang.org/x/exp",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.image",
-		Path: "code.google.com/p/go.image",
+		Path: "golang.org/x/image",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.net",
-		Path: "code.google.com/p/go.net",
+		Path: "golang.org/x/net",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.sys",
-		Path: "code.google.com/p/go.sys",
+		Path: "golang.org/x/sys",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.talks",
-		Path: "code.google.com/p/go.talks",
+		Path: "golang.org/x/talks",
 	},
 	{
 		Kind: "subrepo",
 		Name: "go.tools",
-		Path: "code.google.com/p/go.tools",
+		Path: "golang.org/x/tools",
 	},
 }
 
diff --git a/dashboard/app/build/test.go b/dashboard/app/build/test.go
index 86b2197..34a1c39 100644
--- a/dashboard/app/build/test.go
+++ b/dashboard/app/build/test.go
@@ -41,7 +41,7 @@
 	"Log",
 }
 
-const testPkg = "code.google.com/p/go.test"
+const testPkg = "golang.org/x/test"
 
 var testPackage = &Package{Name: "Test", Kind: "subrepo", Path: testPkg}
 
diff --git a/dashboard/builder/env.go b/dashboard/builder/env.go
index 18bbbe0..b97db99 100644
--- a/dashboard/builder/env.go
+++ b/dashboard/builder/env.go
@@ -15,7 +15,7 @@
 	"runtime"
 	"strings"
 
-	"code.google.com/p/go.tools/go/vcs"
+	"golang.org/x/tools/go/vcs"
 )
 
 // builderEnv represents the environment that a Builder will run tests in.
diff --git a/dashboard/builder/main.go b/dashboard/builder/main.go
index eec0585..a5caf08 100644
--- a/dashboard/builder/main.go
+++ b/dashboard/builder/main.go
@@ -22,7 +22,7 @@
 	"strings"
 	"time"
 
-	"code.google.com/p/go.tools/go/vcs"
+	"golang.org/x/tools/go/vcs"
 )
 
 const (
@@ -55,7 +55,7 @@
 	buildTool      = flag.String("tool", "go", "Tool to build.")
 	gcPath         = flag.String("gcpath", "code.google.com/p/go", "Path to download gc from")
 	gccPath        = flag.String("gccpath", "https://github.com/mirrors/gcc.git", "Path to download gcc from")
-	benchPath      = flag.String("benchpath", "code.google.com/p/go.benchmarks/bench", "Path to download benchmarks from")
+	benchPath      = flag.String("benchpath", "golang.org/x/benchmarks/bench", "Path to download benchmarks from")
 	failAll        = flag.Bool("fail", false, "fail all builds")
 	parallel       = flag.Bool("parallel", false, "Build multiple targets in parallel")
 	buildTimeout   = flag.Duration("buildTimeout", 60*time.Minute, "Maximum time to wait for builds and tests")
diff --git a/dashboard/builder/vcs.go b/dashboard/builder/vcs.go
index e31c4ce..9d94bdc 100644
--- a/dashboard/builder/vcs.go
+++ b/dashboard/builder/vcs.go
@@ -14,7 +14,7 @@
 	"strings"
 	"sync"
 
-	"code.google.com/p/go.tools/go/vcs"
+	"golang.org/x/tools/go/vcs"
 )
 
 // Repo represents a mercurial repository.
diff --git a/dashboard/env/linux-x86-base/scripts/build-go-builder.sh b/dashboard/env/linux-x86-base/scripts/build-go-builder.sh
index 1448fc5..097ac17 100755
--- a/dashboard/env/linux-x86-base/scripts/build-go-builder.sh
+++ b/dashboard/env/linux-x86-base/scripts/build-go-builder.sh
@@ -10,11 +10,11 @@
 curl -s https://storage.googleapis.com/gobuilder/go-snap.tar.gz | tar x --no-same-owner -zv -C $GOROOT
 (cd $GOROOT/src && hg pull -r $GO_REV -u && find && ./make.bash)
 
-GO_TOOLS=$GOPATH/src/code.google.com/p/go.tools
+GO_TOOLS=$GOPATH/src/golang.org/x/tools
 mkdir -p $GO_TOOLS
 curl -s https://storage.googleapis.com/gobuilder/go.tools-snap.tar.gz | tar x --no-same-owner -zv -C $GO_TOOLS
 
 mkdir -p $PREFIX/bin
-(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install code.google.com/p/go.tools/dashboard/builder)
+(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install golang.org/x/tools/dashboard/builder)
 
 rm -fR $GOROOT/bin $GOROOT/pkg $GOPATH
diff --git a/dashboard/env/linux-x86-clang/scripts/build-go-builder.sh b/dashboard/env/linux-x86-clang/scripts/build-go-builder.sh
index 1448fc5..097ac17 100755
--- a/dashboard/env/linux-x86-clang/scripts/build-go-builder.sh
+++ b/dashboard/env/linux-x86-clang/scripts/build-go-builder.sh
@@ -10,11 +10,11 @@
 curl -s https://storage.googleapis.com/gobuilder/go-snap.tar.gz | tar x --no-same-owner -zv -C $GOROOT
 (cd $GOROOT/src && hg pull -r $GO_REV -u && find && ./make.bash)
 
-GO_TOOLS=$GOPATH/src/code.google.com/p/go.tools
+GO_TOOLS=$GOPATH/src/golang.org/x/tools
 mkdir -p $GO_TOOLS
 curl -s https://storage.googleapis.com/gobuilder/go.tools-snap.tar.gz | tar x --no-same-owner -zv -C $GO_TOOLS
 
 mkdir -p $PREFIX/bin
-(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install code.google.com/p/go.tools/dashboard/builder)
+(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install golang.org/x/tools/dashboard/builder)
 
 rm -fR $GOROOT/bin $GOROOT/pkg $GOPATH
diff --git a/dashboard/env/linux-x86-nacl/scripts/build-go-builder.sh b/dashboard/env/linux-x86-nacl/scripts/build-go-builder.sh
index c4a7962..10bf847 100755
--- a/dashboard/env/linux-x86-nacl/scripts/build-go-builder.sh
+++ b/dashboard/env/linux-x86-nacl/scripts/build-go-builder.sh
@@ -10,12 +10,12 @@
 curl -s https://storage.googleapis.com/gobuilder/go-snap.tar.gz | tar x --no-same-owner -zv -C $GOROOT
 (cd $GOROOT/src && hg pull -r $GO_REV -u && find && ./make.bash)
 
-GO_TOOLS=$GOPATH/src/code.google.com/p/go.tools
+GO_TOOLS=$GOPATH/src/golang.org/x/tools
 mkdir -p $GO_TOOLS
 curl -s https://storage.googleapis.com/gobuilder/go.tools-snap.tar.gz | tar x --no-same-owner -zv -C $GO_TOOLS
 
 mkdir -p $PREFIX/bin
-(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install code.google.com/p/go.tools/dashboard/builder)
+(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install golang.org/x/tools/dashboard/builder)
 
 rm -fR $GOROOT/bin $GOROOT/pkg $GOPATH
 
diff --git a/dashboard/env/linux-x86-sid/scripts/build-go-builder.sh b/dashboard/env/linux-x86-sid/scripts/build-go-builder.sh
index 1448fc5..097ac17 100755
--- a/dashboard/env/linux-x86-sid/scripts/build-go-builder.sh
+++ b/dashboard/env/linux-x86-sid/scripts/build-go-builder.sh
@@ -10,11 +10,11 @@
 curl -s https://storage.googleapis.com/gobuilder/go-snap.tar.gz | tar x --no-same-owner -zv -C $GOROOT
 (cd $GOROOT/src && hg pull -r $GO_REV -u && find && ./make.bash)
 
-GO_TOOLS=$GOPATH/src/code.google.com/p/go.tools
+GO_TOOLS=$GOPATH/src/golang.org/x/tools
 mkdir -p $GO_TOOLS
 curl -s https://storage.googleapis.com/gobuilder/go.tools-snap.tar.gz | tar x --no-same-owner -zv -C $GO_TOOLS
 
 mkdir -p $PREFIX/bin
-(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install code.google.com/p/go.tools/dashboard/builder)
+(cd $GO_TOOLS && hg pull -r $BUILDER_REV -u && GOBIN=$PREFIX/bin /goroot/bin/go install golang.org/x/tools/dashboard/builder)
 
 rm -fR $GOROOT/bin $GOROOT/pkg $GOPATH
diff --git a/dashboard/watcher/watcher.go b/dashboard/watcher/watcher.go
index c7d3c5c..7c145f5 100644
--- a/dashboard/watcher/watcher.go
+++ b/dashboard/watcher/watcher.go
@@ -548,7 +548,7 @@
 
 // subrepoList fetches a list of sub-repositories from the dashboard
 // and returns them as a slice of base import paths.
-// Eg, []string{"code.google.com/p/go.tools", "code.google.com/p/go.net"}.
+// Eg, []string{"golang.org/x/tools", "golang.org/x/net"}.
 func subrepoList() ([]string, error) {
 	r, err := http.Get(*dashboard + "packages?kind=subrepo")
 	if err != nil {
diff --git a/go/buildutil/allpackages_test.go b/go/buildutil/allpackages_test.go
index ee741d9..552ad6c 100644
--- a/go/buildutil/allpackages_test.go
+++ b/go/buildutil/allpackages_test.go
@@ -8,7 +8,7 @@
 	"go/build"
 	"testing"
 
-	"code.google.com/p/go.tools/go/buildutil"
+	"golang.org/x/tools/go/buildutil"
 )
 
 func TestAllPackages(t *testing.T) {
@@ -24,7 +24,7 @@
 		t.Errorf("Found only %d packages, want at least %d", len(all), wantAtLeast)
 	}
 
-	for _, want := range []string{"fmt", "crypto/sha256", "code.google.com/p/go.tools/go/buildutil"} {
+	for _, want := range []string{"fmt", "crypto/sha256", "golang.org/x/tools/go/buildutil"} {
 		if !set[want] {
 			t.Errorf("Package %q not found; got %s", want, all)
 		}
diff --git a/go/buildutil/util_test.go b/go/buildutil/util_test.go
index f0db26c..f156829 100644
--- a/go/buildutil/util_test.go
+++ b/go/buildutil/util_test.go
@@ -11,7 +11,7 @@
 	"runtime"
 	"testing"
 
-	"code.google.com/p/go.tools/go/buildutil"
+	"golang.org/x/tools/go/buildutil"
 )
 
 func TestContainingPackage(t *testing.T) {
@@ -23,8 +23,8 @@
 		{goroot + "/src/fmt/print.go", "fmt"},
 		{goroot + "/src/encoding/json/foo.go", "encoding/json"},
 		{goroot + "/src/encoding/missing/foo.go", "(not found)"},
-		{gopath + "/src/code.google.com/p/go.tools/go/buildutil/util_test.go",
-			"code.google.com/p/go.tools/go/buildutil"},
+		{gopath + "/src/golang.org/x/tools/go/buildutil/util_test.go",
+			"golang.org/x/tools/go/buildutil"},
 	} {
 		file, want := test[0], test[1]
 		bp, err := buildutil.ContainingPackage(&build.Default, ".", file)
diff --git a/go/callgraph/callgraph.go b/go/callgraph/callgraph.go
index 68ed230..d0e12d8 100644
--- a/go/callgraph/callgraph.go
+++ b/go/callgraph/callgraph.go
@@ -43,7 +43,7 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/ssa"
+	"golang.org/x/tools/go/ssa"
 )
 
 // A Graph represents a call graph.
diff --git a/go/callgraph/util.go b/go/callgraph/util.go
index 2532fd8..a8f8903 100644
--- a/go/callgraph/util.go
+++ b/go/callgraph/util.go
@@ -4,7 +4,7 @@
 
 package callgraph
 
-import "code.google.com/p/go.tools/go/ssa"
+import "golang.org/x/tools/go/ssa"
 
 // This file provides various utilities over call graphs, such as
 // visitation and path search.
diff --git a/go/gccgoimporter/gccgoinstallation.go b/go/gccgoimporter/gccgoinstallation.go
index 266fbac..1c56cf5 100644
--- a/go/gccgoimporter/gccgoinstallation.go
+++ b/go/gccgoimporter/gccgoinstallation.go
@@ -11,7 +11,7 @@
 	"path/filepath"
 	"strings"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // Information about a specific installation of gccgo.
diff --git a/go/gccgoimporter/gccgoinstallation_test.go b/go/gccgoimporter/gccgoinstallation_test.go
index 64c9890..9ab928d 100644
--- a/go/gccgoimporter/gccgoinstallation_test.go
+++ b/go/gccgoimporter/gccgoinstallation_test.go
@@ -8,7 +8,7 @@
 	"runtime"
 	"testing"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 var importablePackages = [...]string{
diff --git a/go/gccgoimporter/importer.go b/go/gccgoimporter/importer.go
index dc02383..a2b772b 100644
--- a/go/gccgoimporter/importer.go
+++ b/go/gccgoimporter/importer.go
@@ -16,8 +16,8 @@
 	"path/filepath"
 	"strings"
 
-	"code.google.com/p/go.tools/go/importer"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/importer"
+	"golang.org/x/tools/go/types"
 )
 
 // A PackageInit describes an imported package that needs initialization.
diff --git a/go/gccgoimporter/importer_test.go b/go/gccgoimporter/importer_test.go
index 2276768..722151f 100644
--- a/go/gccgoimporter/importer_test.go
+++ b/go/gccgoimporter/importer_test.go
@@ -12,7 +12,7 @@
 	"runtime"
 	"testing"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 type importerTest struct {
diff --git a/go/gccgoimporter/parser.go b/go/gccgoimporter/parser.go
index 6c4faf6..883c350 100644
--- a/go/gccgoimporter/parser.go
+++ b/go/gccgoimporter/parser.go
@@ -14,8 +14,8 @@
 	"strings"
 	"text/scanner"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 type parser struct {
diff --git a/go/gccgoimporter/parser_test.go b/go/gccgoimporter/parser_test.go
index f084a63..1f0f12a 100644
--- a/go/gccgoimporter/parser_test.go
+++ b/go/gccgoimporter/parser_test.go
@@ -10,7 +10,7 @@
 	"testing"
 	"text/scanner"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 var typeParserTests = []struct {
diff --git a/go/gcimporter/gcimporter.go b/go/gcimporter/gcimporter.go
index f0e0412..b6844b4 100644
--- a/go/gcimporter/gcimporter.go
+++ b/go/gcimporter/gcimporter.go
@@ -19,8 +19,8 @@
 	"strings"
 	"text/scanner"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 // debugging/development support
diff --git a/go/gcimporter/gcimporter_test.go b/go/gcimporter/gcimporter_test.go
index 877489b..a20853a 100644
--- a/go/gcimporter/gcimporter_test.go
+++ b/go/gcimporter/gcimporter_test.go
@@ -15,7 +15,7 @@
 	"testing"
 	"time"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 var gcPath string // Go compiler path
diff --git a/go/importer/export.go b/go/importer/export.go
index 9579963..5930eaf 100644
--- a/go/importer/export.go
+++ b/go/importer/export.go
@@ -11,8 +11,8 @@
 	"go/ast"
 	"strings"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 // debugging support
diff --git a/go/importer/import.go b/go/importer/import.go
index 16c6eba..3604c98 100644
--- a/go/importer/import.go
+++ b/go/importer/import.go
@@ -14,8 +14,8 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 // ImportData imports a package from the serialized package data
diff --git a/go/importer/import_test.go b/go/importer/import_test.go
index d21ad7e..3a2560c 100644
--- a/go/importer/import_test.go
+++ b/go/importer/import_test.go
@@ -20,8 +20,8 @@
 	"testing"
 	"time"
 
-	"code.google.com/p/go.tools/go/gcimporter"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/gcimporter"
+	"golang.org/x/tools/go/types"
 )
 
 var fset = token.NewFileSet()
diff --git a/go/importer/predefined.go b/go/importer/predefined.go
index 3965b0a..a4db568 100644
--- a/go/importer/predefined.go
+++ b/go/importer/predefined.go
@@ -4,7 +4,7 @@
 
 package importer
 
-import "code.google.com/p/go.tools/go/types"
+import "golang.org/x/tools/go/types"
 
 const (
 	magic   = "\n$$ exports $$\n"
diff --git a/go/loader/loader.go b/go/loader/loader.go
index f64b3b6..566108f 100644
--- a/go/loader/loader.go
+++ b/go/loader/loader.go
@@ -136,9 +136,9 @@
 	"os"
 	"strings"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/go/gcimporter"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/go/gcimporter"
+	"golang.org/x/tools/go/types"
 )
 
 // Config specifies the configuration for a program to load.
diff --git a/go/loader/loader_test.go b/go/loader/loader_test.go
index 0421ec0..c239c63 100644
--- a/go/loader/loader_test.go
+++ b/go/loader/loader_test.go
@@ -16,7 +16,7 @@
 	"testing"
 	"time"
 
-	"code.google.com/p/go.tools/go/loader"
+	"golang.org/x/tools/go/loader"
 )
 
 func loadFromArgs(args []string) (prog *loader.Program, rest []string, err error) {
diff --git a/go/loader/source_test.go b/go/loader/source_test.go
index 919237d..d0ca4a7 100644
--- a/go/loader/source_test.go
+++ b/go/loader/source_test.go
@@ -13,9 +13,9 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
 )
 
 // findInterval parses input and returns the [start, end) positions of
diff --git a/go/loader/stdlib_test.go b/go/loader/stdlib_test.go
index 6994264..eb439a1 100644
--- a/go/loader/stdlib_test.go
+++ b/go/loader/stdlib_test.go
@@ -23,9 +23,9 @@
 	"testing"
 	"time"
 
-	"code.google.com/p/go.tools/go/buildutil"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/buildutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
 )
 
 func TestStdlib(t *testing.T) {
diff --git a/go/pointer/analysis.go b/go/pointer/analysis.go
index bc68795..8887a86 100644
--- a/go/pointer/analysis.go
+++ b/go/pointer/analysis.go
@@ -16,10 +16,10 @@
 	"runtime/debug"
 	"sort"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 const (
diff --git a/go/pointer/api.go b/go/pointer/api.go
index 890017a..a81c586 100644
--- a/go/pointer/api.go
+++ b/go/pointer/api.go
@@ -10,10 +10,10 @@
 	"go/token"
 	"io"
 
-	"code.google.com/p/go.tools/container/intsets"
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/container/intsets"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 // A Config formulates a pointer analysis problem for Analyze().
diff --git a/go/pointer/callgraph.go b/go/pointer/callgraph.go
index 6706291..48e152e 100644
--- a/go/pointer/callgraph.go
+++ b/go/pointer/callgraph.go
@@ -10,7 +10,7 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/ssa"
+	"golang.org/x/tools/go/ssa"
 )
 
 type cgnode struct {
diff --git a/go/pointer/constraint.go b/go/pointer/constraint.go
index 0f363b9..e6371cc 100644
--- a/go/pointer/constraint.go
+++ b/go/pointer/constraint.go
@@ -5,7 +5,7 @@
 package pointer
 
 import (
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 type constraint interface {
diff --git a/go/pointer/example_test.go b/go/pointer/example_test.go
index 3606ed6..eecfd30 100644
--- a/go/pointer/example_test.go
+++ b/go/pointer/example_test.go
@@ -8,10 +8,10 @@
 	"fmt"
 	"sort"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/pointer"
-	"code.google.com/p/go.tools/go/ssa"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/pointer"
+	"golang.org/x/tools/go/ssa"
 )
 
 // This program demonstrates how to use the pointer analysis to
diff --git a/go/pointer/gen.go b/go/pointer/gen.go
index cfd8241..12f4d79 100644
--- a/go/pointer/gen.go
+++ b/go/pointer/gen.go
@@ -14,9 +14,9 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 var (
diff --git a/go/pointer/hvn.go b/go/pointer/hvn.go
index 0e1c6b2..a3ef1f3 100644
--- a/go/pointer/hvn.go
+++ b/go/pointer/hvn.go
@@ -162,8 +162,8 @@
 	"io"
 	"reflect"
 
-	"code.google.com/p/go.tools/container/intsets"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/container/intsets"
+	"golang.org/x/tools/go/types"
 )
 
 // A peLabel is a pointer-equivalence label: two nodes with the same
diff --git a/go/pointer/intrinsics.go b/go/pointer/intrinsics.go
index cb0100e..251c0e2 100644
--- a/go/pointer/intrinsics.go
+++ b/go/pointer/intrinsics.go
@@ -18,8 +18,8 @@
 import (
 	"fmt"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 // Instances of 'intrinsic' generate analysis constraints for calls to
diff --git a/go/pointer/labels.go b/go/pointer/labels.go
index 48a9f0b..cf6ef20 100644
--- a/go/pointer/labels.go
+++ b/go/pointer/labels.go
@@ -9,8 +9,8 @@
 	"go/token"
 	"strings"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 // A Label is an entity that may be pointed to by a pointer, map,
diff --git a/go/pointer/pointer_test.go b/go/pointer/pointer_test.go
index 7c10693..aeffb5c 100644
--- a/go/pointer/pointer_test.go
+++ b/go/pointer/pointer_test.go
@@ -21,13 +21,13 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/pointer"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/ssautil"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/pointer"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/ssautil"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 var inputs = []string{
diff --git a/go/pointer/reflect.go b/go/pointer/reflect.go
index 6e5c54c..7e9c280 100644
--- a/go/pointer/reflect.go
+++ b/go/pointer/reflect.go
@@ -28,9 +28,9 @@
 	"fmt"
 	"reflect"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 func init() {
diff --git a/go/pointer/solve.go b/go/pointer/solve.go
index ce5d07c..ad1a65f 100644
--- a/go/pointer/solve.go
+++ b/go/pointer/solve.go
@@ -10,7 +10,7 @@
 import (
 	"fmt"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 type solverState struct {
diff --git a/go/pointer/stdlib_test.go b/go/pointer/stdlib_test.go
index c5869ec..214cdfc 100644
--- a/go/pointer/stdlib_test.go
+++ b/go/pointer/stdlib_test.go
@@ -10,7 +10,7 @@
 //
 // Because it is relatively slow, the --stdlib flag must be enabled for
 // this test to run:
-//    % go test -v code.google.com/p/go.tools/go/pointer --stdlib
+//    % go test -v golang.org/x/tools/go/pointer --stdlib
 
 import (
 	"flag"
@@ -19,10 +19,10 @@
 	"testing"
 	"time"
 
-	"code.google.com/p/go.tools/go/buildutil"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/ssautil"
+	"golang.org/x/tools/go/buildutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/ssautil"
 )
 
 var runStdlibTest = flag.Bool("stdlib", false, "Run the (slow) stdlib test")
diff --git a/go/pointer/util.go b/go/pointer/util.go
index e3ac4fc..88bada8 100644
--- a/go/pointer/util.go
+++ b/go/pointer/util.go
@@ -13,8 +13,8 @@
 	"runtime"
 	"time"
 
-	"code.google.com/p/go.tools/container/intsets"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/container/intsets"
+	"golang.org/x/tools/go/types"
 )
 
 // CanPoint reports whether the type T is pointerlike,
diff --git a/go/ssa/builder.go b/go/ssa/builder.go
index e45bffa..6e1739c 100644
--- a/go/ssa/builder.go
+++ b/go/ssa/builder.go
@@ -37,8 +37,8 @@
 	"sync"
 	"sync/atomic"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 type opaqueType struct {
diff --git a/go/ssa/builder_test.go b/go/ssa/builder_test.go
index 1df98b5..858db4b 100644
--- a/go/ssa/builder_test.go
+++ b/go/ssa/builder_test.go
@@ -11,9 +11,9 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 func isEmpty(f *ssa.Function) bool { return f.Blocks == nil }
diff --git a/go/ssa/const.go b/go/ssa/const.go
index 44a1ee7..304096e 100644
--- a/go/ssa/const.go
+++ b/go/ssa/const.go
@@ -11,8 +11,8 @@
 	"go/token"
 	"strconv"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/types"
 )
 
 // NewConst returns a new constant of the specified value and type.
diff --git a/go/ssa/create.go b/go/ssa/create.go
index 7a3629e..7f57101 100644
--- a/go/ssa/create.go
+++ b/go/ssa/create.go
@@ -13,8 +13,8 @@
 	"os"
 	"sync"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
 )
 
 // BuilderMode is a bitmask of options for diagnostics and checking.
diff --git a/go/ssa/emit.go b/go/ssa/emit.go
index 0963d4f..84246c6 100644
--- a/go/ssa/emit.go
+++ b/go/ssa/emit.go
@@ -11,7 +11,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // emitNew emits to f a new (heap Alloc) instruction allocating an
diff --git a/go/ssa/example_test.go b/go/ssa/example_test.go
index f78ce63..5253c88 100644
--- a/go/ssa/example_test.go
+++ b/go/ssa/example_test.go
@@ -8,8 +8,8 @@
 	"fmt"
 	"os"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
 )
 
 // This program demonstrates how to run the SSA builder on a "Hello,
@@ -26,7 +26,7 @@
 //
 // Build and run the ssadump.go program if you want a standalone tool
 // with similar functionality. It is located at
-// code.google.com/p/go.tools/cmd/ssadump.
+// golang.org/x/tools/cmd/ssadump.
 //
 func Example() {
 	const hello = `
diff --git a/go/ssa/func.go b/go/ssa/func.go
index 52c4991..3f08d3e 100644
--- a/go/ssa/func.go
+++ b/go/ssa/func.go
@@ -15,7 +15,7 @@
 	"os"
 	"strings"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // addEdge adds a control-flow graph edge from from to to.
diff --git a/go/ssa/interp/external.go b/go/ssa/interp/external.go
index 26a39da..e3a8ee0 100644
--- a/go/ssa/interp/external.go
+++ b/go/ssa/interp/external.go
@@ -15,8 +15,8 @@
 	"time"
 	"unsafe"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 type externalFn func(fr *frame, args []value) value
diff --git a/go/ssa/interp/interp.go b/go/ssa/interp/interp.go
index 80c620c..d674c25 100644
--- a/go/ssa/interp/interp.go
+++ b/go/ssa/interp/interp.go
@@ -51,8 +51,8 @@
 	"reflect"
 	"runtime"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 type continuation int
diff --git a/go/ssa/interp/interp_test.go b/go/ssa/interp/interp_test.go
index a732960..456fdaf 100644
--- a/go/ssa/interp/interp_test.go
+++ b/go/ssa/interp/interp_test.go
@@ -16,10 +16,10 @@
 	"testing"
 	"time"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/interp"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/interp"
+	"golang.org/x/tools/go/types"
 )
 
 // Each line contains a space-separated list of $GOROOT/test/
@@ -208,7 +208,7 @@
 		interp.CapturedOutput = nil
 	}()
 
-	hint = fmt.Sprintf("To dump SSA representation, run:\n%% go build code.google.com/p/go.tools/cmd/ssadump && ./ssadump -build=CFP %s\n", input)
+	hint = fmt.Sprintf("To dump SSA representation, run:\n%% go build golang.org/x/tools/cmd/ssadump && ./ssadump -build=CFP %s\n", input)
 
 	iprog, err := conf.Load()
 	if err != nil {
@@ -247,7 +247,7 @@
 	var out bytes.Buffer
 	interp.CapturedOutput = &out
 
-	hint = fmt.Sprintf("To trace execution, run:\n%% go build code.google.com/p/go.tools/cmd/ssadump && ./ssadump -build=C -run --interp=T %s\n", input)
+	hint = fmt.Sprintf("To trace execution, run:\n%% go build golang.org/x/tools/cmd/ssadump && ./ssadump -build=C -run --interp=T %s\n", input)
 	exitCode := interp.Interpret(mainPkg, 0, &types.StdSizes{8, 8}, inputs[0], []string{})
 
 	// The definition of success varies with each file.
diff --git a/go/ssa/interp/map.go b/go/ssa/interp/map.go
index 5e93e7f..5dbaf0a 100644
--- a/go/ssa/interp/map.go
+++ b/go/ssa/interp/map.go
@@ -12,7 +12,7 @@
 // concurrent map access.
 
 import (
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 type hashable interface {
diff --git a/go/ssa/interp/ops.go b/go/ssa/interp/ops.go
index b1fca00..fe7d679 100644
--- a/go/ssa/interp/ops.go
+++ b/go/ssa/interp/ops.go
@@ -12,9 +12,9 @@
 	"sync"
 	"unsafe"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 // If the target program panics, the interpreter panics with this type.
diff --git a/go/ssa/interp/reflect.go b/go/ssa/interp/reflect.go
index 91a0b30..051695c 100644
--- a/go/ssa/interp/reflect.go
+++ b/go/ssa/interp/reflect.go
@@ -16,8 +16,8 @@
 	"reflect"
 	"unsafe"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 type opaqueType struct {
diff --git a/go/ssa/interp/value.go b/go/ssa/interp/value.go
index f3257b9..a8d27ee 100644
--- a/go/ssa/interp/value.go
+++ b/go/ssa/interp/value.go
@@ -42,9 +42,9 @@
 	"sync"
 	"unsafe"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 type value interface{}
diff --git a/go/ssa/lift.go b/go/ssa/lift.go
index 1f190fe..3771f61 100644
--- a/go/ssa/lift.go
+++ b/go/ssa/lift.go
@@ -47,7 +47,7 @@
 	"math/big"
 	"os"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // If true, perform sanity checking and show diagnostic information at
diff --git a/go/ssa/lvalue.go b/go/ssa/lvalue.go
index 2e8eb9d..e58bc24 100644
--- a/go/ssa/lvalue.go
+++ b/go/ssa/lvalue.go
@@ -11,7 +11,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // An lvalue represents an assignable location that may appear on the
diff --git a/go/ssa/methods.go b/go/ssa/methods.go
index 322c885..1ef725c 100644
--- a/go/ssa/methods.go
+++ b/go/ssa/methods.go
@@ -9,7 +9,7 @@
 import (
 	"fmt"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // Method returns the Function implementing method sel, building
diff --git a/go/ssa/print.go b/go/ssa/print.go
index f9b3d17..9fda3a4 100644
--- a/go/ssa/print.go
+++ b/go/ssa/print.go
@@ -14,8 +14,8 @@
 	"reflect"
 	"sort"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 // relName returns the name of v relative to i.
diff --git a/go/ssa/sanity.go b/go/ssa/sanity.go
index 69d80e2..3fd6747 100644
--- a/go/ssa/sanity.go
+++ b/go/ssa/sanity.go
@@ -13,7 +13,7 @@
 	"os"
 	"strings"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 type sanity struct {
diff --git a/go/ssa/source.go b/go/ssa/source.go
index 8f0d0f3..02b0260 100644
--- a/go/ssa/source.go
+++ b/go/ssa/source.go
@@ -14,7 +14,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // EnclosingFunction returns the function that contains the syntax
diff --git a/go/ssa/source_test.go b/go/ssa/source_test.go
index 0fa68d8..203da7f 100644
--- a/go/ssa/source_test.go
+++ b/go/ssa/source_test.go
@@ -16,11 +16,11 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 func TestObjValueLookup(t *testing.T) {
diff --git a/go/ssa/ssa.go b/go/ssa/ssa.go
index 09fa75f..8543992 100644
--- a/go/ssa/ssa.go
+++ b/go/ssa/ssa.go
@@ -13,10 +13,10 @@
 	"go/token"
 	"sync"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 // A Program is a partial or complete Go program converted to SSA form.
diff --git a/go/ssa/ssautil/switch.go b/go/ssa/ssautil/switch.go
index ae030c4..70fff9c 100644
--- a/go/ssa/ssautil/switch.go
+++ b/go/ssa/ssautil/switch.go
@@ -23,8 +23,8 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 // A ConstCase represents a single constant comparison.
diff --git a/go/ssa/ssautil/switch_test.go b/go/ssa/ssautil/switch_test.go
index 86d5bfb..ae11058 100644
--- a/go/ssa/ssautil/switch_test.go
+++ b/go/ssa/ssautil/switch_test.go
@@ -9,9 +9,9 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/ssautil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/ssautil"
 )
 
 func TestSwitches(t *testing.T) {
diff --git a/go/ssa/ssautil/visit.go b/go/ssa/ssautil/visit.go
index 6b8c5d2..8dc6694 100644
--- a/go/ssa/ssautil/visit.go
+++ b/go/ssa/ssautil/visit.go
@@ -4,7 +4,7 @@
 
 package ssautil
 
-import "code.google.com/p/go.tools/go/ssa"
+import "golang.org/x/tools/go/ssa"
 
 // This file defines utilities for visiting the SSA representation of
 // a Program.
diff --git a/go/ssa/stdlib_test.go b/go/ssa/stdlib_test.go
index bfe7216..c45923b 100644
--- a/go/ssa/stdlib_test.go
+++ b/go/ssa/stdlib_test.go
@@ -16,10 +16,10 @@
 	"testing"
 	"time"
 
-	"code.google.com/p/go.tools/go/buildutil"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/ssautil"
+	"golang.org/x/tools/go/buildutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/ssautil"
 )
 
 func TestStdlib(t *testing.T) {
diff --git a/go/ssa/testmain.go b/go/ssa/testmain.go
index f11e3b7..422c7db 100644
--- a/go/ssa/testmain.go
+++ b/go/ssa/testmain.go
@@ -14,7 +14,7 @@
 	"os"
 	"strings"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // FindTests returns the list of packages that define at least one Test,
diff --git a/go/ssa/testmain_test.go b/go/ssa/testmain_test.go
index 3a9eacc..04a41fc 100644
--- a/go/ssa/testmain_test.go
+++ b/go/ssa/testmain_test.go
@@ -12,8 +12,8 @@
 	"sort"
 	"testing"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/ssa"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/ssa"
 )
 
 func create(t *testing.T, content string) []*ssa.Package {
diff --git a/go/ssa/util.go b/go/ssa/util.go
index 738ac7b..1cf15e8 100644
--- a/go/ssa/util.go
+++ b/go/ssa/util.go
@@ -13,7 +13,7 @@
 	"io"
 	"os"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 func unreachable() {
diff --git a/go/ssa/wrappers.go b/go/ssa/wrappers.go
index d23075f..10c8a64 100644
--- a/go/ssa/wrappers.go
+++ b/go/ssa/wrappers.go
@@ -22,7 +22,7 @@
 import (
 	"fmt"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // -- wrappers -----------------------------------------------------------
diff --git a/go/types/api.go b/go/types/api.go
index 1bb8934..908b0f0 100644
--- a/go/types/api.go
+++ b/go/types/api.go
@@ -28,7 +28,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // Check type-checks a package and returns the resulting complete package
@@ -118,7 +118,7 @@
 // DefaultImport is the default importer invoked if Config.Import == nil.
 // The declaration:
 //
-//	import _ "code.google.com/p/go.tools/go/gcimporter"
+//	import _ "golang.org/x/tools/go/gcimporter"
 //
 // in a client of go/types will initialize DefaultImport to gcimporter.Import.
 var DefaultImport Importer
diff --git a/go/types/api_test.go b/go/types/api_test.go
index 9b698a1..ad3d30b 100644
--- a/go/types/api_test.go
+++ b/go/types/api_test.go
@@ -13,8 +13,8 @@
 	"strings"
 	"testing"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 func pkgFor(path, source string, info *Info) (*Package, error) {
diff --git a/go/types/builtins.go b/go/types/builtins.go
index 33d7ca3..fc0b7f7 100644
--- a/go/types/builtins.go
+++ b/go/types/builtins.go
@@ -10,7 +10,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // builtin type-checks a call to the built-in specified by id and
diff --git a/go/types/builtins_test.go b/go/types/builtins_test.go
index 9164cf3..e785799 100644
--- a/go/types/builtins_test.go
+++ b/go/types/builtins_test.go
@@ -10,8 +10,8 @@
 	"go/parser"
 	"testing"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 var builtinCalls = []struct {
diff --git a/go/types/check.go b/go/types/check.go
index 4c21984..5b30a30 100644
--- a/go/types/check.go
+++ b/go/types/check.go
@@ -10,7 +10,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // debugging/development support
diff --git a/go/types/check_test.go b/go/types/check_test.go
index dddae30..aefaa5a 100644
--- a/go/types/check_test.go
+++ b/go/types/check_test.go
@@ -36,8 +36,8 @@
 	"strings"
 	"testing"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 var (
diff --git a/go/types/conversions.go b/go/types/conversions.go
index e951887..32cc822 100644
--- a/go/types/conversions.go
+++ b/go/types/conversions.go
@@ -6,7 +6,7 @@
 
 package types
 
-import "code.google.com/p/go.tools/go/exact"
+import "golang.org/x/tools/go/exact"
 
 // Conversion type-checks the conversion T(x).
 // The result is in x.
diff --git a/go/types/decl.go b/go/types/decl.go
index f0d0760..3273fd4 100644
--- a/go/types/decl.go
+++ b/go/types/decl.go
@@ -8,7 +8,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 func (check *Checker) reportAltDecl(obj Object) {
diff --git a/go/types/eval.go b/go/types/eval.go
index 549aadb..3edb385 100644
--- a/go/types/eval.go
+++ b/go/types/eval.go
@@ -12,7 +12,7 @@
 	"go/parser"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // New is a convenience function to create a new type from a given
diff --git a/go/types/eval_test.go b/go/types/eval_test.go
index d9b6852..14d3327 100644
--- a/go/types/eval_test.go
+++ b/go/types/eval_test.go
@@ -13,8 +13,8 @@
 	"strings"
 	"testing"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 func testEval(t *testing.T, pkg *Package, scope *Scope, str string, typ Type, typStr, valStr string) {
diff --git a/go/types/expr.go b/go/types/expr.go
index cda473f..c55ce6a 100644
--- a/go/types/expr.go
+++ b/go/types/expr.go
@@ -12,7 +12,7 @@
 	"go/token"
 	"math"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 /*
diff --git a/go/types/exprstring_test.go b/go/types/exprstring_test.go
index 8606715..cfd1472 100644
--- a/go/types/exprstring_test.go
+++ b/go/types/exprstring_test.go
@@ -8,7 +8,7 @@
 	"go/parser"
 	"testing"
 
-	. "code.google.com/p/go.tools/go/types"
+	. "golang.org/x/tools/go/types"
 )
 
 var testExprs = []testEntry{
diff --git a/go/types/hilbert_test.go b/go/types/hilbert_test.go
index 298d1ca..b555721 100644
--- a/go/types/hilbert_test.go
+++ b/go/types/hilbert_test.go
@@ -14,7 +14,7 @@
 	"io/ioutil"
 	"testing"
 
-	. "code.google.com/p/go.tools/go/types"
+	. "golang.org/x/tools/go/types"
 )
 
 var (
diff --git a/go/types/issues_test.go b/go/types/issues_test.go
index 95c6f67..04d8b37 100644
--- a/go/types/issues_test.go
+++ b/go/types/issues_test.go
@@ -14,8 +14,8 @@
 	"strings"
 	"testing"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 func TestIssue5770(t *testing.T) {
diff --git a/go/types/object.go b/go/types/object.go
index 37b3fc4..30bc31a 100644
--- a/go/types/object.go
+++ b/go/types/object.go
@@ -10,7 +10,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // TODO(gri) Document factory, accessor methods, and fields. General clean-up.
diff --git a/go/types/operand.go b/go/types/operand.go
index 2545da7..7418eef 100644
--- a/go/types/operand.go
+++ b/go/types/operand.go
@@ -11,7 +11,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // An operandMode specifies the (addressing) mode of an operand.
diff --git a/go/types/resolver.go b/go/types/resolver.go
index 690c44f..e8b2823 100644
--- a/go/types/resolver.go
+++ b/go/types/resolver.go
@@ -14,7 +14,7 @@
 	"strings"
 	"unicode"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // A declInfo describes a package-level const, type, var, or func declaration.
@@ -131,7 +131,7 @@
 	importer := check.conf.Import
 	if importer == nil {
 		if DefaultImport == nil {
-			panic(`no Config.Import or DefaultImport (missing import _ "code.google.com/p/go.tools/go/gcimporter"?)`)
+			panic(`no Config.Import or DefaultImport (missing import _ "golang.org/x/tools/go/gcimporter"?)`)
 		}
 		importer = DefaultImport
 	}
diff --git a/go/types/resolver_test.go b/go/types/resolver_test.go
index 9fc9893..d8af7a0 100644
--- a/go/types/resolver_test.go
+++ b/go/types/resolver_test.go
@@ -12,8 +12,8 @@
 	"sort"
 	"testing"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 var sources = []string{
diff --git a/go/types/self_test.go b/go/types/self_test.go
index e7342de..01d12c7 100644
--- a/go/types/self_test.go
+++ b/go/types/self_test.go
@@ -14,8 +14,8 @@
 	"testing"
 	"time"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 var benchmark = flag.Bool("b", false, "run benchmarks")
diff --git a/go/types/stdlib_test.go b/go/types/stdlib_test.go
index 310e11d..8629022 100644
--- a/go/types/stdlib_test.go
+++ b/go/types/stdlib_test.go
@@ -22,8 +22,8 @@
 	"testing"
 	"time"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 var (
diff --git a/go/types/stmt.go b/go/types/stmt.go
index 9b96436..42580bd 100644
--- a/go/types/stmt.go
+++ b/go/types/stmt.go
@@ -11,7 +11,7 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 func (check *Checker) funcBody(decl *declInfo, name string, sig *Signature, body *ast.BlockStmt) {
diff --git a/go/types/typestring_test.go b/go/types/typestring_test.go
index b003cbb..9aacf85 100644
--- a/go/types/typestring_test.go
+++ b/go/types/typestring_test.go
@@ -10,8 +10,8 @@
 	"go/token"
 	"testing"
 
-	_ "code.google.com/p/go.tools/go/gcimporter"
-	. "code.google.com/p/go.tools/go/types"
+	_ "golang.org/x/tools/go/gcimporter"
+	. "golang.org/x/tools/go/types"
 )
 
 const filename = "<src>"
diff --git a/go/types/typeutil/imports.go b/go/types/typeutil/imports.go
index b7b8f4f..0f4a232 100644
--- a/go/types/typeutil/imports.go
+++ b/go/types/typeutil/imports.go
@@ -1,6 +1,6 @@
 package typeutil
 
-import "code.google.com/p/go.tools/go/types"
+import "golang.org/x/tools/go/types"
 
 // Dependencies returns all dependencies of the specified packages.
 //
diff --git a/go/types/typeutil/imports_test.go b/go/types/typeutil/imports_test.go
index aca6c1a..6f207cf 100644
--- a/go/types/typeutil/imports_test.go
+++ b/go/types/typeutil/imports_test.go
@@ -7,8 +7,8 @@
 	"go/token"
 	"testing"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 func TestDependencies(t *testing.T) {
diff --git a/go/types/typeutil/map.go b/go/types/typeutil/map.go
index 69c3f13..bf1ed2d 100644
--- a/go/types/typeutil/map.go
+++ b/go/types/typeutil/map.go
@@ -11,7 +11,7 @@
 	"fmt"
 	"reflect"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // Map is a hash-table-based mapping from types (types.Type) to
diff --git a/go/types/typeutil/map_test.go b/go/types/typeutil/map_test.go
index 9d2a788..776b5e2 100644
--- a/go/types/typeutil/map_test.go
+++ b/go/types/typeutil/map_test.go
@@ -12,8 +12,8 @@
 import (
 	"testing"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 var (
diff --git a/go/types/typeutil/ui.go b/go/types/typeutil/ui.go
index a17c1a4..af42d2d 100644
--- a/go/types/typeutil/ui.go
+++ b/go/types/typeutil/ui.go
@@ -6,7 +6,7 @@
 
 // This file defines utilities for user interfaces that display types.
 
-import "code.google.com/p/go.tools/go/types"
+import "golang.org/x/tools/go/types"
 
 // IntuitiveMethodSet returns the intuitive method set of a type, T.
 //
diff --git a/go/types/typexpr.go b/go/types/typexpr.go
index d9a4f20..8c4b679 100644
--- a/go/types/typexpr.go
+++ b/go/types/typexpr.go
@@ -12,7 +12,7 @@
 	"sort"
 	"strconv"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 // ident type-checks identifier e and initializes x with the value or type of e.
diff --git a/go/types/universe.go b/go/types/universe.go
index 1494db0..420f938 100644
--- a/go/types/universe.go
+++ b/go/types/universe.go
@@ -10,7 +10,7 @@
 	"go/token"
 	"strings"
 
-	"code.google.com/p/go.tools/go/exact"
+	"golang.org/x/tools/go/exact"
 )
 
 var (
diff --git a/godoc/analysis/analysis.go b/godoc/analysis/analysis.go
index c4ba459..2642495 100644
--- a/godoc/analysis/analysis.go
+++ b/godoc/analysis/analysis.go
@@ -57,11 +57,11 @@
 	"strings"
 	"sync"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/pointer"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/ssautil"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/pointer"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/ssautil"
+	"golang.org/x/tools/go/types"
 )
 
 // -- links ------------------------------------------------------------
@@ -364,7 +364,7 @@
 	}
 
 	// Uncomment to make startup quicker during debugging.
-	//args = []string{"code.google.com/p/go.tools/cmd/godoc"}
+	//args = []string{"golang.org/x/tools/cmd/godoc"}
 	//args = []string{"fmt"}
 
 	if _, err := conf.FromArgs(args, true); err != nil {
diff --git a/godoc/analysis/callgraph.go b/godoc/analysis/callgraph.go
index 2442da7..149b60c 100644
--- a/godoc/analysis/callgraph.go
+++ b/godoc/analysis/callgraph.go
@@ -16,9 +16,9 @@
 	"math/big"
 	"sort"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 // doCallgraph computes the CALLEES and CALLERS relations.
diff --git a/godoc/analysis/implements.go b/godoc/analysis/implements.go
index c806719..f951df4 100644
--- a/godoc/analysis/implements.go
+++ b/godoc/analysis/implements.go
@@ -13,7 +13,7 @@
 import (
 	"sort"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 // computeImplements computes the "implements" relation over all pairs
diff --git a/godoc/analysis/peers.go b/godoc/analysis/peers.go
index aaf1896..e1696e2 100644
--- a/godoc/analysis/peers.go
+++ b/godoc/analysis/peers.go
@@ -15,9 +15,9 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/pointer"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/pointer"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
 )
 
 func (a *analysis) doChannelPeers(ptsets map[ssa.Value]pointer.Pointer) {
diff --git a/godoc/analysis/typeinfo.go b/godoc/analysis/typeinfo.go
index d679a9f..82f2f29 100644
--- a/godoc/analysis/typeinfo.go
+++ b/godoc/analysis/typeinfo.go
@@ -24,9 +24,9 @@
 	"strconv"
 	"strings"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 // TODO(adonovan): audit to make sure it's safe on ill-typed packages.
diff --git a/godoc/cmdline.go b/godoc/cmdline.go
index 8a5a321..5452ca3 100644
--- a/godoc/cmdline.go
+++ b/godoc/cmdline.go
@@ -15,14 +15,14 @@
 	"regexp"
 	"strings"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 const (
 	target    = "/target"
 	cmdPrefix = "cmd/"
 	srcPrefix = "src/"
-	toolsPath = "code.google.com/p/go.tools/cmd/"
+	toolsPath = "golang.org/x/tools/cmd/"
 )
 
 // CommandLine returns godoc results to w.
diff --git a/godoc/cmdline_test.go b/godoc/cmdline_test.go
index 64e1c44..d21c55b 100644
--- a/godoc/cmdline_test.go
+++ b/godoc/cmdline_test.go
@@ -12,8 +12,8 @@
 	"testing"
 	"text/template"
 
-	"code.google.com/p/go.tools/godoc/vfs"
-	"code.google.com/p/go.tools/godoc/vfs/mapfs"
+	"golang.org/x/tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs/mapfs"
 )
 
 // setupGoroot creates temporary directory to act as GOROOT when running tests
diff --git a/godoc/corpus.go b/godoc/corpus.go
index 021fb15..f2c7ebb 100644
--- a/godoc/corpus.go
+++ b/godoc/corpus.go
@@ -9,9 +9,9 @@
 	pathpkg "path"
 	"time"
 
-	"code.google.com/p/go.tools/godoc/analysis"
-	"code.google.com/p/go.tools/godoc/util"
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/analysis"
+	"golang.org/x/tools/godoc/util"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // A Corpus holds all the state related to serving and indexing a
diff --git a/godoc/index.go b/godoc/index.go
index 73885f3..725121a 100644
--- a/godoc/index.go
+++ b/godoc/index.go
@@ -62,8 +62,8 @@
 	"time"
 	"unicode"
 
-	"code.google.com/p/go.tools/godoc/util"
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/util"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // ----------------------------------------------------------------------------
diff --git a/godoc/index_test.go b/godoc/index_test.go
index 562c97a..a16bdcb 100644
--- a/godoc/index_test.go
+++ b/godoc/index_test.go
@@ -11,7 +11,7 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/godoc/vfs/mapfs"
+	"golang.org/x/tools/godoc/vfs/mapfs"
 )
 
 func newCorpus(t *testing.T) *Corpus {
diff --git a/godoc/meta.go b/godoc/meta.go
index ae8ee5a..41ade39 100644
--- a/godoc/meta.go
+++ b/godoc/meta.go
@@ -12,7 +12,7 @@
 	"strings"
 	"time"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 var (
diff --git a/godoc/parser.go b/godoc/parser.go
index 6ecad73..4e644d6 100644
--- a/godoc/parser.go
+++ b/godoc/parser.go
@@ -14,7 +14,7 @@
 	"go/token"
 	pathpkg "path"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 var linePrefix = []byte("//line ")
diff --git a/godoc/pres.go b/godoc/pres.go
index 2bf71f1..a8f8b2b 100644
--- a/godoc/pres.go
+++ b/godoc/pres.go
@@ -10,7 +10,7 @@
 	"sync"
 	"text/template"
 
-	"code.google.com/p/go.tools/godoc/vfs/httpfs"
+	"golang.org/x/tools/godoc/vfs/httpfs"
 )
 
 // SearchResultFunc functions return an HTML body for displaying search results.
diff --git a/godoc/redirect/redirect.go b/godoc/redirect/redirect.go
index 4fb5898..29e3c4e 100644
--- a/godoc/redirect/redirect.go
+++ b/godoc/redirect/redirect.go
@@ -86,8 +86,8 @@
 	"/build":      "http://build.golang.org",
 	"/change":     "https://code.google.com/p/go/source/list",
 	"/cl":         "https://gocodereview.appspot.com/",
-	"/cmd/godoc/": "http://godoc.org/code.google.com/p/go.tools/cmd/godoc/",
-	"/cmd/vet/":   "http://godoc.org/code.google.com/p/go.tools/cmd/vet/",
+	"/cmd/godoc/": "http://godoc.org/golang.org/x/tools/cmd/godoc/",
+	"/cmd/vet/":   "http://godoc.org/golang.org/x/tools/cmd/vet/",
 	"/issue":      "https://code.google.com/p/go/issues",
 	"/issue/new":  "https://code.google.com/p/go/issues/entry",
 	"/issues":     "https://code.google.com/p/go/issues",
diff --git a/godoc/server.go b/godoc/server.go
index 5923b79..7963cd0 100644
--- a/godoc/server.go
+++ b/godoc/server.go
@@ -27,9 +27,9 @@
 	"text/template"
 	"time"
 
-	"code.google.com/p/go.tools/godoc/analysis"
-	"code.google.com/p/go.tools/godoc/util"
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/analysis"
+	"golang.org/x/tools/godoc/util"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // handlerServer is a migration from an old godoc http Handler type.
diff --git a/godoc/static/doc.go b/godoc/static/doc.go
index e1e75da..5ef96ae 100644
--- a/godoc/static/doc.go
+++ b/godoc/static/doc.go
@@ -4,5 +4,5 @@
 
 // Package static exports a map of static file content that supports the godoc
 // user interface. The map should be used with the mapfs package, see
-// code.google.com/p/go.tools/godoc/vfs/mapfs.
+// golang.org/x/tools/godoc/vfs/mapfs.
 package static
diff --git a/godoc/static/package.html b/godoc/static/package.html
index cd5da3b..cc69e61 100644
--- a/godoc/static/package.html
+++ b/godoc/static/package.html
@@ -289,13 +289,13 @@
 	Install them with "<a href="/cmd/go/#hdr-Download_and_install_packages_and_dependencies">go get</a>".
 	</p>
 	<ul>
-		<li><a href="//godoc.org/code.google.com/p/go.crypto">crypto</a> — additional cryptography packages.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.image">image</a> — additional imaging packages.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.net">net</a> — additional networking packages.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.sys">sys</a> — packages for making system calls.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.text">text</a> — packages for working with text.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.tools">tools</a> — godoc, vet, cover, and other tools.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.exp">exp</a> — experimental code (handle with care; may change without warning).</li>
+		<li><a href="//godoc.org/golang.org/x/crypto">crypto</a> — additional cryptography packages.</li>
+		<li><a href="//godoc.org/golang.org/x/image">image</a> — additional imaging packages.</li>
+		<li><a href="//godoc.org/golang.org/x/net">net</a> — additional networking packages.</li>
+		<li><a href="//godoc.org/golang.org/x/sys">sys</a> — packages for making system calls.</li>
+		<li><a href="//godoc.org/golang.org/x/text">text</a> — packages for working with text.</li>
+		<li><a href="//godoc.org/golang.org/x/tools">tools</a> — godoc, vet, cover, and other tools.</li>
+		<li><a href="//godoc.org/golang.org/x/exp">exp</a> — experimental code (handle with care; may change without warning).</li>
 	</ul>
 
 	<h3 id="community">Community</h3>
diff --git a/godoc/static/static.go b/godoc/static/static.go
index 99d2dd5..593d433 100644
--- a/godoc/static/static.go
+++ b/godoc/static/static.go
@@ -1800,13 +1800,13 @@
 	Install them with "<a href="/cmd/go/#hdr-Download_and_install_packages_and_dependencies">go get</a>".
 	</p>
 	<ul>
-		<li><a href="//godoc.org/code.google.com/p/go.crypto">crypto</a> — additional cryptography packages.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.image">image</a> — additional imaging packages.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.net">net</a> — additional networking packages.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.sys">sys</a> — packages for making system calls.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.text">text</a> — packages for working with text.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.tools">tools</a> — godoc, vet, cover, and other tools.</li>
-		<li><a href="//godoc.org/code.google.com/p/go.exp">exp</a> — experimental code (handle with care; may change without warning).</li>
+		<li><a href="//godoc.org/golang.org/x/crypto">crypto</a> — additional cryptography packages.</li>
+		<li><a href="//godoc.org/golang.org/x/image">image</a> — additional imaging packages.</li>
+		<li><a href="//godoc.org/golang.org/x/net">net</a> — additional networking packages.</li>
+		<li><a href="//godoc.org/golang.org/x/sys">sys</a> — packages for making system calls.</li>
+		<li><a href="//godoc.org/golang.org/x/text">text</a> — packages for working with text.</li>
+		<li><a href="//godoc.org/golang.org/x/tools">tools</a> — godoc, vet, cover, and other tools.</li>
+		<li><a href="//godoc.org/golang.org/x/exp">exp</a> — experimental code (handle with care; may change without warning).</li>
 	</ul>
 
 	<h3 id="community">Community</h3>
diff --git a/godoc/template.go b/godoc/template.go
index 325bc8c..eda5874 100644
--- a/godoc/template.go
+++ b/godoc/template.go
@@ -38,7 +38,7 @@
 	"regexp"
 	"strings"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // Functions in this file panic on error, but the panic is recovered
diff --git a/godoc/util/util.go b/godoc/util/util.go
index 1371bcd..d6416df 100644
--- a/godoc/util/util.go
+++ b/godoc/util/util.go
@@ -11,7 +11,7 @@
 	"time"
 	"unicode/utf8"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // An RWValue wraps a value and permits mutually exclusive
diff --git a/godoc/vfs/gatefs/gatefs.go b/godoc/vfs/gatefs/gatefs.go
index 2e6c47f..cb8ec03 100644
--- a/godoc/vfs/gatefs/gatefs.go
+++ b/godoc/vfs/gatefs/gatefs.go
@@ -10,7 +10,7 @@
 	"fmt"
 	"os"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // New returns a new FileSystem that delegates to fs.
diff --git a/godoc/vfs/httpfs/httpfs.go b/godoc/vfs/httpfs/httpfs.go
index 51a4fff..e4beeec 100644
--- a/godoc/vfs/httpfs/httpfs.go
+++ b/godoc/vfs/httpfs/httpfs.go
@@ -11,7 +11,7 @@
 	"net/http"
 	"os"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 func New(fs vfs.FileSystem) http.FileSystem {
diff --git a/godoc/vfs/mapfs/mapfs.go b/godoc/vfs/mapfs/mapfs.go
index 550c4ba..6da3c0a 100644
--- a/godoc/vfs/mapfs/mapfs.go
+++ b/godoc/vfs/mapfs/mapfs.go
@@ -14,7 +14,7 @@
 	"strings"
 	"time"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // New returns a new FileSystem from the provided map.
diff --git a/godoc/vfs/zipfs/zipfs.go b/godoc/vfs/zipfs/zipfs.go
index 99869c5..0e04a4a 100644
--- a/godoc/vfs/zipfs/zipfs.go
+++ b/godoc/vfs/zipfs/zipfs.go
@@ -27,7 +27,7 @@
 	"strings"
 	"time"
 
-	"code.google.com/p/go.tools/godoc/vfs"
+	"golang.org/x/tools/godoc/vfs"
 )
 
 // zipFI is the zip-file based implementation of FileInfo
diff --git a/imports/fix.go b/imports/fix.go
index 47a98f9..11415cf 100644
--- a/imports/fix.go
+++ b/imports/fix.go
@@ -16,7 +16,7 @@
 	"strings"
 	"sync"
 
-	"code.google.com/p/go.tools/astutil"
+	"golang.org/x/tools/astutil"
 )
 
 // importToGroup is a list of functions which map from an import path to
diff --git a/imports/imports.go b/imports/imports.go
index 0da153c..b97529e 100644
--- a/imports/imports.go
+++ b/imports/imports.go
@@ -20,7 +20,7 @@
 	"strconv"
 	"strings"
 
-	"code.google.com/p/go.tools/astutil"
+	"golang.org/x/tools/astutil"
 )
 
 // Options specifies options for processing files.
diff --git a/oracle/callees.go b/oracle/callees.go
index 8584403..c8be728 100644
--- a/oracle/callees.go
+++ b/oracle/callees.go
@@ -10,9 +10,9 @@
 	"go/token"
 	"sort"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // Callees reports the possible callees of the function call site
diff --git a/oracle/callers.go b/oracle/callers.go
index f970eb5..dde803b 100644
--- a/oracle/callers.go
+++ b/oracle/callers.go
@@ -8,9 +8,9 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // Callers reports the possible callers of the function
diff --git a/oracle/callgraph.go b/oracle/callgraph.go
index feda3db..09f2205 100644
--- a/oracle/callgraph.go
+++ b/oracle/callgraph.go
@@ -9,10 +9,10 @@
 	"go/token"
 	"sort"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // doCallgraph displays the entire callgraph of the current program,
diff --git a/oracle/callstack.go b/oracle/callstack.go
index 3269fd2..4b2e380 100644
--- a/oracle/callstack.go
+++ b/oracle/callstack.go
@@ -8,9 +8,9 @@
 	"fmt"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/callgraph"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/callgraph"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // Callstack displays an arbitrary path from a root of the callgraph
diff --git a/oracle/definition.go b/oracle/definition.go
index 16ba5eb..0f149b2 100644
--- a/oracle/definition.go
+++ b/oracle/definition.go
@@ -9,8 +9,8 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // definition reports the location of the definition of an identifier.
diff --git a/oracle/describe.go b/oracle/describe.go
index 8e43407..0f2ea4b 100644
--- a/oracle/describe.go
+++ b/oracle/describe.go
@@ -13,12 +13,12 @@
 	"os"
 	"strings"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // describe describes the syntax node denoted by the query position,
diff --git a/oracle/freevars.go b/oracle/freevars.go
index 5582318..84a06b0 100644
--- a/oracle/freevars.go
+++ b/oracle/freevars.go
@@ -11,8 +11,8 @@
 	"go/token"
 	"sort"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // freevars displays the lexical (not package-level) free variables of
diff --git a/oracle/implements.go b/oracle/implements.go
index 3dcf42e..d07a02c 100644
--- a/oracle/implements.go
+++ b/oracle/implements.go
@@ -12,8 +12,8 @@
 	"sort"
 	"strings"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // Implements displays the "implements" relation as it pertains to the
diff --git a/oracle/oracle_test.go b/oracle/oracle_test.go
index 3bbd23f..987defe 100644
--- a/oracle/oracle_test.go
+++ b/oracle/oracle_test.go
@@ -23,7 +23,7 @@
 // correctness, since it is critical information.)
 //
 // Run this test with:
-// 	% go test code.google.com/p/go.tools/oracle -update
+// 	% go test golang.org/x/tools/oracle -update
 // to update the golden files.
 
 import (
@@ -44,8 +44,8 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/oracle"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/oracle"
 )
 
 var updateFlag = flag.Bool("update", false, "Update the golden files.")
diff --git a/oracle/peers.go b/oracle/peers.go
index 90baf65..bcff11c 100644
--- a/oracle/peers.go
+++ b/oracle/peers.go
@@ -10,10 +10,10 @@
 	"go/token"
 	"sort"
 
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/ssa/ssautil"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/ssa/ssautil"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // peers enumerates, for a given channel send (or receive) operation,
diff --git a/oracle/pointsto.go b/oracle/pointsto.go
index df8d57f..8f633ad 100644
--- a/oracle/pointsto.go
+++ b/oracle/pointsto.go
@@ -10,12 +10,12 @@
 	"go/token"
 	"sort"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/pointer"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/pointer"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // pointsto runs the pointer analysis on the selected expression,
diff --git a/oracle/pos.go b/oracle/pos.go
index 4ae30a6..6ca019a 100644
--- a/oracle/pos.go
+++ b/oracle/pos.go
@@ -11,7 +11,7 @@
 	"strconv"
 	"strings"
 
-	"code.google.com/p/go.tools/astutil"
+	"golang.org/x/tools/astutil"
 )
 
 // parseOctothorpDecimal returns the numeric value if s matches "#%d",
diff --git a/oracle/referrers.go b/oracle/referrers.go
index 91af9cd..037b6db 100644
--- a/oracle/referrers.go
+++ b/oracle/referrers.go
@@ -10,8 +10,8 @@
 	"go/token"
 	"sort"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // Referrers reports all identifiers that resolve to the same object
diff --git a/oracle/what.go b/oracle/what.go
index 108bef2..9ffc067 100644
--- a/oracle/what.go
+++ b/oracle/what.go
@@ -14,8 +14,8 @@
 	"sort"
 	"strings"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // what reports all the information about the query selection that can be
diff --git a/playground/socket/socket.go b/playground/socket/socket.go
index 9b44664..fe1ac9e 100644
--- a/playground/socket/socket.go
+++ b/playground/socket/socket.go
@@ -35,7 +35,7 @@
 	"time"
 	"unicode/utf8"
 
-	"code.google.com/p/go.net/websocket"
+	"golang.org/x/net/websocket"
 )
 
 // RunScripts specifies whether the socket handler should execute shell scripts
diff --git a/refactor/README b/refactor/README
index a6edb13..a315784 100644
--- a/refactor/README
+++ b/refactor/README
@@ -1 +1 @@
-code.google.com/p/go.tools/refactor: libraries for refactoring tools.
+golang.org/x/tools/refactor: libraries for refactoring tools.
diff --git a/refactor/eg/eg_test.go b/refactor/eg/eg_test.go
index dde037b..6e9fc4b 100644
--- a/refactor/eg/eg_test.go
+++ b/refactor/eg/eg_test.go
@@ -12,10 +12,10 @@
 	"strings"
 	"testing"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/refactor/eg"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/refactor/eg"
 )
 
 // TODO(adonovan): more tests:
diff --git a/refactor/eg/match.go b/refactor/eg/match.go
index b1c0cf3..f524505 100644
--- a/refactor/eg/match.go
+++ b/refactor/eg/match.go
@@ -8,9 +8,9 @@
 	"os"
 	"reflect"
 
-	"code.google.com/p/go.tools/go/exact"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/exact"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
 )
 
 // matchExpr reports whether pattern x matches y.
diff --git a/refactor/eg/rewrite.go b/refactor/eg/rewrite.go
index 7e90ee9..61cfe88 100644
--- a/refactor/eg/rewrite.go
+++ b/refactor/eg/rewrite.go
@@ -14,8 +14,8 @@
 	"strconv"
 	"strings"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/go/types"
 )
 
 // Transform applies the transformation to the specified parsed file,
diff --git a/refactor/importgraph/graph.go b/refactor/importgraph/graph.go
index bbf8879..bbdbb33 100644
--- a/refactor/importgraph/graph.go
+++ b/refactor/importgraph/graph.go
@@ -10,7 +10,7 @@
 	"go/build"
 	"sync"
 
-	"code.google.com/p/go.tools/go/buildutil"
+	"golang.org/x/tools/go/buildutil"
 )
 
 // A Graph is an import dependency graph, either forward or reverse.
diff --git a/refactor/importgraph/graph_test.go b/refactor/importgraph/graph_test.go
index 694fbdb..522e5cb 100644
--- a/refactor/importgraph/graph_test.go
+++ b/refactor/importgraph/graph_test.go
@@ -6,12 +6,12 @@
 	"sort"
 	"testing"
 
-	"code.google.com/p/go.tools/refactor/importgraph"
+	"golang.org/x/tools/refactor/importgraph"
 
 	_ "crypto/hmac" // just for test, below
 )
 
-const this = "code.google.com/p/go.tools/refactor/importgraph"
+const this = "golang.org/x/tools/refactor/importgraph"
 
 func TestBuild(t *testing.T) {
 	saved := runtime.GOMAXPROCS(8) // Build is highly parallel
diff --git a/refactor/lexical/lexical_test.go b/refactor/lexical/lexical_test.go
index 56feb1d..ada6595 100644
--- a/refactor/lexical/lexical_test.go
+++ b/refactor/lexical/lexical_test.go
@@ -8,8 +8,8 @@
 	"go/build"
 	"testing"
 
-	"code.google.com/p/go.tools/go/buildutil"
-	"code.google.com/p/go.tools/go/loader"
+	"golang.org/x/tools/go/buildutil"
+	"golang.org/x/tools/go/loader"
 )
 
 func TestStdlib(t *testing.T) {
@@ -28,8 +28,8 @@
 
 	// Throw in a number of go.tools packages too.
 	pkgs = append(pkgs,
-		"code.google.com/p/go.tools/cmd/godoc",
-		"code.google.com/p/go.tools/refactor/lexical")
+		"golang.org/x/tools/cmd/godoc",
+		"golang.org/x/tools/refactor/lexical")
 
 	// Load, parse and type-check the program.
 	conf := loader.Config{
diff --git a/refactor/rename/rename.el b/refactor/rename/rename.el
index c31a465..9268358 100644
--- a/refactor/rename/rename.el
+++ b/refactor/rename/rename.el
@@ -5,8 +5,8 @@
 ;;; Integration of the 'gorename' tool into Emacs.
 ;;;
 ;;; To install:
-;;; % go get code.google.com/p/go.tools/cmd/gorename
-;;; % go build code.google.com/p/go.tools/cmd/gorename
+;;; % go get golang.org/x/tools/cmd/gorename
+;;; % go build golang.org/x/tools/cmd/gorename
 ;;; % mv gorename $HOME/bin/         # or elsewhere on $PATH
 ;;;
 ;;; The go-rename-command variable can be customized to specify an
diff --git a/refactor/rename/spec.go b/refactor/rename/spec.go
index dc390f0..571e817 100644
--- a/refactor/rename/spec.go
+++ b/refactor/rename/spec.go
@@ -20,9 +20,9 @@
 	"strconv"
 	"strings"
 
-	"code.google.com/p/go.tools/go/buildutil"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/buildutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
 )
 
 // A spec specifies an entity to rename.
diff --git a/cmd/html2article/conv.go b/cmd/html2article/conv.go
index d2f8640..ae14a25 100644
--- a/cmd/html2article/conv.go
+++ b/cmd/html2article/conv.go
@@ -3,7 +3,7 @@
 // license that can be found in the LICENSE file.
 
 // This program takes an HTML file and outputs a corresponding article file in
 // present format. See: code.google.com/p/go.tools/present
 package main
 
 import (
@@ -19,8 +19,8 @@
 	"regexp"
 	"strings"
 
-	"code.google.com/p/go.net/html"
-	"code.google.com/p/go.net/html/atom"
+	"golang.org/x/net/html"
+	"golang.org/x/net/html/atom"
 )
 
 func main() {
@@ -3,7 +3,7 @@
 
 // This program takes an HTML file and outputs a corresponding article file in
-// present format. See: code.google.com/p/go.tools/present
+// present format. See: golang.org/x/tools/present
 package main
 
diff --git a/oracle/oracle.go b/oracle/oracle.go
index a0d8638..55566c3 100644
--- a/oracle/oracle.go
+++ b/oracle/oracle.go
@@ -3,7 +3,7 @@
 // license that can be found in the LICENSE file.
 
 // Package oracle contains the implementation of the oracle tool whose
 // command-line is provided by code.google.com/p/go.tools/cmd/oracle.
 //
 // http://golang.org/s/oracle-design
 // http://golang.org/s/oracle-user-manual
@@ -56,12 +56,12 @@
 	"go/token"
 	"io"
 
-	"code.google.com/p/go.tools/astutil"
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/pointer"
-	"code.google.com/p/go.tools/go/ssa"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/oracle/serial"
+	"golang.org/x/tools/astutil"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/pointer"
+	"golang.org/x/tools/go/ssa"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/oracle/serial"
 )
 
 // An Oracle holds the program state required for one or more queries.
@@ -3,7 +3,7 @@
 
 // Package oracle contains the implementation of the oracle tool whose
-// command-line is provided by code.google.com/p/go.tools/cmd/oracle.
+// command-line is provided by golang.org/x/tools/cmd/oracle.
 //
 // http://golang.org/s/oracle-design
diff --git a/refactor/eg/eg.go b/refactor/eg/eg.go
index f080b2e..933078f 100644
--- a/refactor/eg/eg.go
+++ b/refactor/eg/eg.go
@@ -1,5 +1,5 @@
 // Package eg implements the example-based refactoring tool whose
 // command-line is defined in code.google.com/p/go.tools/cmd/eg.
 package eg
 
 import (
@@ -10,8 +10,8 @@
 	"go/token"
 	"os"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
 )
 
 const Help = `
@@ -1,5 +1,5 @@
 // Package eg implements the example-based refactoring tool whose
-// command-line is defined in code.google.com/p/go.tools/cmd/eg.
+// command-line is defined in golang.org/x/tools/cmd/eg.
 package eg
 
diff --git a/refactor/lexical/lexical.go b/refactor/lexical/lexical.go
index 485aab5..31dfb0f 100644
--- a/refactor/lexical/lexical.go
+++ b/refactor/lexical/lexical.go
@@ -35,7 +35,7 @@
 	"os"
 	"strconv"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 const trace = false
@@ -745,7 +745,7 @@
 	return r.result
 }
 
 // -- Plundered from code.google.com/p/go.tools/go/ssa -----------------
 
 // deref returns a pointer's element type; otherwise it returns typ.
 func deref(typ types.Type) types.Type {
@@ -745,7 +745,7 @@
 }
 
-// -- Plundered from code.google.com/p/go.tools/go/ssa -----------------
+// -- Plundered from golang.org/x/tools/go/ssa -----------------
 
 // deref returns a pointer's element type; otherwise it returns typ.
diff --git a/refactor/rename/check.go b/refactor/rename/check.go
index 09f5d94..15741b1 100644
--- a/refactor/rename/check.go
+++ b/refactor/rename/check.go
@@ -11,10 +11,10 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/refactor/lexical"
-	"code.google.com/p/go.tools/refactor/satisfy"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/refactor/lexical"
+	"golang.org/x/tools/refactor/satisfy"
 )
 
 // errorf reports an error (e.g. conflict) and prevents file modification.
@@ -645,7 +645,7 @@
 	return nil
 }
 
 // -- Plundered from code.google.com/p/go.tools/go/ssa -----------------
 
 func isInterface(T types.Type) bool {
 	_, ok := T.Underlying().(*types.Interface)
@@ -645,7 +645,7 @@
 }
 
-// -- Plundered from code.google.com/p/go.tools/go/ssa -----------------
+// -- Plundered from golang.org/x/tools/go/ssa -----------------
 
 func isInterface(T types.Type) bool {
diff --git a/refactor/rename/rename.go b/refactor/rename/rename.go
index 12fc149..25e1071 100644
--- a/refactor/rename/rename.go
+++ b/refactor/rename/rename.go
@@ -3,7 +3,7 @@
 // license that can be found in the LICENSE file.
 
 // Package rename contains the implementation of the 'gorename' command
 // whose main function is in code.google.com/p/go.tools/refactor/rename.
 // See that package for the command documentation.
 package rename
 
@@ -20,10 +20,10 @@
 	"sort"
 	"strings"
 
-	"code.google.com/p/go.tools/go/loader"
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/refactor/importgraph"
-	"code.google.com/p/go.tools/refactor/satisfy"
+	"golang.org/x/tools/go/loader"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/refactor/importgraph"
+	"golang.org/x/tools/refactor/satisfy"
 )
 
 var (
@@ -3,7 +3,7 @@
 
 // Package rename contains the implementation of the 'gorename' command
-// whose main function is in code.google.com/p/go.tools/refactor/rename.
+// whose main function is in golang.org/x/tools/refactor/rename.
 // See that package for the command documentation.
 package rename
diff --git a/refactor/rename/util.go b/refactor/rename/util.go
index 67f48e8..bf9e350 100644
--- a/refactor/rename/util.go
+++ b/refactor/rename/util.go
@@ -13,7 +13,7 @@
 	"strings"
 	"unicode"
 
-	"code.google.com/p/go.tools/go/types"
+	"golang.org/x/tools/go/types"
 )
 
 func objectKind(obj types.Object) string {
@@ -77,7 +77,7 @@
 	return '0' <= ch && ch <= '9' || ch >= 0x80 && unicode.IsDigit(ch)
 }
 
 // -- Plundered from code.google.com/p/go.tools/oracle -----------------
 
 // sameFile returns true if x and y have the same basename and denote
 // the same file.
@@ -77,7 +77,7 @@
 }
 
-// -- Plundered from code.google.com/p/go.tools/oracle -----------------
+// -- Plundered from golang.org/x/tools/oracle -----------------
 
 // sameFile returns true if x and y have the same basename and denote
diff --git a/refactor/satisfy/find.go b/refactor/satisfy/find.go
index 897fbc1..8671cc5 100644
--- a/refactor/satisfy/find.go
+++ b/refactor/satisfy/find.go
@@ -49,8 +49,8 @@
 	"go/ast"
 	"go/token"
 
-	"code.google.com/p/go.tools/go/types"
-	"code.google.com/p/go.tools/go/types/typeutil"
+	"golang.org/x/tools/go/types"
+	"golang.org/x/tools/go/types/typeutil"
 )
 
 // A Constraint records the fact that the RHS type does and must
@@ -697,7 +697,7 @@
 	}
 }
 
 // -- Plundered from code.google.com/p/go.tools/go/ssa -----------------
 
 // deref returns a pointer's element type; otherwise it returns typ.
 func deref(typ types.Type) types.Type {
@@ -697,7 +697,7 @@
 }
 
-// -- Plundered from code.google.com/p/go.tools/go/ssa -----------------
+// -- Plundered from golang.org/x/tools/go/ssa -----------------
 
 // deref returns a pointer's element type; otherwise it returns typ.